#Sinnesael et al.,
#
#This script documents the analyses that were carried out in the 'Astrochron' (Meyers, 2014)
#package for R (R Core Team, ref).

setwd("location of your working directory")

#---INITIATION---

#load the 'astrochron package'
library(astrochron)

#load the data
NGR_K=read(d=0,h="no",srt=T,ave=T,genplot=F)
pXRF_K=read(d=0,h="no",srt=T,ave=T,genplot=F)
Kerarmor_pXRF_K=read(d=0,h="no",srt=T,ave=T,genplot=F)
Posto_NGR_K=read(d=0,h="no",srt=T,ave=T,genplot=F)
Posto_NGR_Th=read(d=0,h="no",srt=T,ave=T,genplot=F)
Posto_NGR_U=read(d=0,h="no",srt=T,ave=T,genplot=F)


#Plot data
plot(NGR_K,type="l")
plot(pXRF_K,type="l")
plot(Kerarmor_pXRF_K,type="l")
plot(Posto_NGR_K,type="l")
plot(Posto_NGR_Th,type="l")
plot(Posto_NGR_U,type="l")


### PREP ###
######################################
#linterp
data=linterp(NGR_K)
pXRF_K=linterp(pXRF_K)
Kerarmor_pXRF_K=linterp(Kerarmor_pXRF_K)
Posto_NGR_K = linterp(Posto_NGR_K)
Posto_NGR_Th = linterp(Posto_NGR_Th)
Posto_NGR_U = linterp(Posto_NGR_U)

#lin, 1p detrend
data=detrend(data)
pXRF_K=detrend(pXRF_K)
Kerarmor_pXRF_K=detrend(Kerarmor_pXRF_K)
Posto_NGR_K=detrend(Posto_NGR_K)
Posto_NGR_Th=detrend(Posto_NGR_Th)
Posto_NGR_U=detrend(Posto_NGR_U)
depth = Posto_NGR_K[,1]

######################################
#---SPECTRAL ANALYSIS - MORGAT - NGR K--

#periodogram-mtm
periodogram(data,xmax=4)
mtm(data,tbw=2,xmax=4,pl=1,output=0,siglevel=0.9)

#evolutionary - eha
EHA_output=eha(data,fmin=0.00,fmax=4.0,step=0.1,win=3,ydir=1,output=3,xlab="test",ylab="test",genplot=2)

#Bandpass filtering
NGR_F1_BP = bandpass(data,flow =0.5,fhigh=1.0) # BP 2.0-1.0 m cycle
NGR_F2_BP = bandpass(data,flow =1.8,fhigh=2.2) # BP ~0.5 m cycle

writeT("NGR_F1_BP.tab",NGR_F1_BP)
writeT("NGR_F2_BP.tab",NGR_F2_BP)

######################################
#---SPECTRAL ANALYSIS - MORGAT - pXRF K--

periodogram(pXRF_K,xmax=10)
mtm(pXRF_K,tbw=2,xmax=10,pl=1,output=0,siglevel=0.8)

#evolutionary - eha
EHA_output=eha(pXRF_K,fmin=0.00,fmax=10.0,step=0.05,win=2,ydir=1,output=3,xlab="test",ylab="test",genplot=2)

#Bandpass filtering
pXRF_F1_BP = bandpass(pXRF_K,flow =0.5,fhigh=1.0) # BP 2.0-1.0 m cycle
pXRF_F2_BP = bandpass(pXRF_K,flow =1.8,fhigh=2.2) # BP ~0.5 m cycle
pXRF_F3_BP = bandpass(pXRF_K,flow =3,fhigh=4.5) # BP ~0.25-0.30 m cycle

writeT("pXRF_F1_BP.tab",pXRF_F1_BP)
writeT("pXRF_F2_BP.tab",pXRF_F2_BP)
writeT("pXRF_F3_BP.tab",pXRF_F3_BP)

######################################
#---SPECTRAL ANALYSIS - KERARMOR - pXRF K--
periodogram(Kerarmor_pXRF_K,xmax=10)
mtm(Kerarmor_pXRF_K,tbw=2,xmax=10,pl=1,output=0,siglevel=0.8)

#evolutionary - eha
EHA_output=eha(Kerarmor_pXRF_K,fmin=0.00,fmax=6.0,step=0.05,win=3,ydir=1,output=3,xlab="test",ylab="test",genplot=2)

#Bandpass filtering
pXRF_F1_BP_Kerarmor = bandpass(Kerarmor_pXRF_K,flow =0.5,fhigh=2.0) # BP 2.0-1.0 m cycle

writeT("pXRF_F1_BP_Kerarmor.tab",pXRF_F1_BP_Kerarmor)

#---TIMEOPT---
# evaluate precession modulations
targetE=c(125,95)
targetP=c(20.8,19.8,17.2,17.1)
targetP=c(20,17)

#---TimeOpt
timeOpt(pXRF_K,sedmin=0.1,sedmax=3,targetP=targetP,targetE=targetE,numsed=100,fit=1,output=0)

#---eTimeOpt
res=eTimeOpt(pXRF_K,win=2,step=0.05,sedmin=0.5,sedmax=3,numsed=50,limit=F,fit=1,targetP=targetP,targetE=targetE,output=1,ydir=1)

######################################
#---SPECTRAL ANALYSIS-POSTO NGR K--

periodogram(Posto_NGR_K,xmax=1)
mtm(Posto_NGR_K,tbw=2,xmax=1,pl=1,output=0,siglevel=0.8)
mtm(Posto_NGR_Th,tbw=2,xmax=1,pl=1,output=0,siglevel=0.9)
mtm(Posto_NGR_U,tbw=2,xmax=1,pl=1,output=0,siglevel=0.9)

trend = lowpass(Posto_NGR_K,fcut=0.0333)
plot(trend,type='l')
detrended = Posto_NGR_K[,2] - trend[,2]
Posto_NGR_K_detrended = cbind(depth,detrended)
plot(Posto_NGR_K_detrended,type='l')

writeT("Posto_NGR_K_detrended.tab",Posto_NGR_K_detrended)
writeT("trend.tab",trend)

#evolutionary - eha
EHA_output=eha(Posto_NGR_K,fmin=0.00,fmax=0.6,step=0.5,win=75,ydir=1,output=3,xlab="test",ylab="test",genplot=2)
EHA_output=eha(Posto_NGR_Th,fmin=0.00,fmax=1.0,step=0.5,win=75,ydir=1,output=3,xlab="test",ylab="test",genplot=2)
EHA_output=eha(Posto_NGR_U,fmin=0.00,fmax=1.0,step=0.5,win=75,ydir=1,output=3,xlab="test",ylab="test",genplot=2)

mtm(Posto_NGR_K_detrended,tbw=2,xmax=1,pl=1,output=0,siglevel=0.8)
EHA_output=eha(Posto_NGR_K_detrended,fmin=0.00,fmax=0.6,step=0.5,win=50,ydir=1,output=3,xlab="test",ylab="test",genplot=2)


#Bandpass filtering
NGR_F1_BP = bandpass(Posto_NGR_K,flow =0.5,fhigh=1.0) # BP 2.0-1.5 m cycle
NGR_F2_BP = bandpass(Posto_NGR_K,flow =1.8,fhigh=2.2) # BP 0.5 m cycle

writeT("NGR_F1_BP.tab",NGR_F1_BP)
writeT("NGR_F2_BP.tab",NGR_F2_BP)

#################"



